MapKitMapControllerBase class abstract

Abstract base class for MapKit map controllers.

This class provides a basic structure for map controllers, holding a reference to a mapkit.Map object.

Implementers

Constructors

MapKitMapControllerBase({required Map map})
Constructs a MapKitMapControllerBase with the given mapkit.Map instance.

Properties

hashCode int
The hash code for this object.
no setterinherited
map Map
The MapKit map instance managed by this controller.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited