MapKitMapControllerBase class abstract
Abstract base class for MapKit map controllers.
This class provides a basic structure for map controllers, holding a reference to a mapkit.Map object.
- Implementers
Constructors
- MapKitMapControllerBase({required Map map})
- Constructs a MapKitMapControllerBase with the given mapkit.Map instance.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited